<?php
/**
 * @version     1.0.0
 * @package     plg_arkeditor
 * @copyright   Copyright (C) 2017. All rights reserved.
 * @license     GNU General Public License version 2 or later; see LICENSE.txt
 * @author      WebxSolution Ltd - http://www.arkextensions.com
 */

defined( '_JEXEC' ) or die;

class PlgTemplateXTDArkEditor extends JPlugin
{
	/**
	 * @var		object	Application object
	 */
	public $app;

	/**
	 * @var		string	Ark Extension Name
	 */
	protected $name		= 'arkeditor';

	/**
	 * @var		bool	Load the Language File on Instantiation.
	 */
	protected $autoloadLanguage = true;

	/**
	 * Display An Ark Extension Button.
	 *
	 * @param	string	$name	The Name of the Template (e.g. ark_bounce).
	 * @param	string	$asset	The Name of the Asset Being Edited.
	 * @param	int		$author	The ID of the Current Author/User.
	 *
	 * @return	object	A Two Element object of (button, menu items) or false if not Authorised.
	 */
	public function onDisplayToolbar( $name, $asset, $author )
	{
		$user 		= JFactory::getUser();
		$extension 	= $this->app->input->get( 'option' );
		$params		= JComponentHelper::getParams( 'com_' . $this->name );

		if( !$params->get( 'enable_inline', true ) )
		{
			return false;
		}//end if

		if( 
			$user->authorise( 'core.edit', $asset )
			|| $user->authorise( 'core.create', $asset )
			|| ( count( $user->getAuthorisedCategories( $asset, 'core.create' ) ) > 0 )
			|| ($user->authorise( 'core.edit.own', $asset ) && $author == $user->id )
			|| ( count( $user->getAuthorisedCategories( $extension, 'core.edit') ) > 0 )
			|| ( count( $user->getAuthorisedCategories( $extension, 'core.edit.own') ) > 0 && $author == $user->id )
		)
		{
			// Supply root data & assets
			$data 					= new stdClass;
			$data->id				= $this->name;
			$data->assets			= JLayoutHelper::render( $this->name . '.xtd', null, dirname( __FILE__ ) . chr( 47 ) . 'layouts' );

			// Supply main toolbar button (on by default, switched off by JS)
			$data->button			= new stdClass;
			$data->button->text		= JText::_( 'PLG_TEMPLATE-XTD_EDIT_BTN' );
			$data->button->icon		= 'pencil';
			$data->button->attrs	= array( 'class' => 'ark-text-success' );
			$data->menu				= array();

			// Supply sub menu actions
			$button					= new stdClass;
			$button->type			= 'link';
			$button->text			= JText::_( 'PLG_TEMPLATE-XTD_ENABLE_BTN' );
			$button->icon			= 'pencil';
			$button->iconcolour		= 'success';
			$button->attrs			= array( 'ark-toolbar-action' => 'enable', 'hidden' => '' );
			$data->menu[]			= $button;

			$button					= new stdClass;
			$button->type			= 'link';
			$button->text			= JText::_( 'PLG_TEMPLATE-XTD_DISABLE_BTN' );
			$button->icon			= 'close';
			$button->iconcolour		= 'danger';
			$button->attrs			= array( 'ark-toolbar-action' => 'disable' );
			$data->menu[]			= $button;

			$data->menu[]			= (object)array( 'type' => 'divider' );

			$button					= new stdClass;
			$button->type			= 'link';
			$button->text			= JText::_( 'PLG_TEMPLATE-XTD_SAVE_BTN' );
			$button->icon			= 'check';
			$button->iconcolour		= 'primary';
			$button->attrs			= array( 'ark-toolbar-action' => 'save' );
			$data->menu[]			= $button;

			return $data;
		}//end if

		return false;
	}//end function
}//end class
